==> RoughlyEnoughItems-fabric-19.0.806-sources.jar: me/shedaniel/rei/impl/client/gui/widget/entrylist/CachingEntryRenderer.java <==
/*
 * This file is licensed under the MIT License, part of Roughly Enough Items.
 * Copyright (c) 2018, 2019, 2020, 2021, 2022, 2023 shedaniel
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */

package me.shedaniel.rei.impl.client.gui.widget.entrylist;

import me.shedaniel.math.Rectangle;
import me.shedaniel.rei.api.client.entry.renderer.BatchedEntryRenderer;
import me.shedaniel.rei.api.client.gui.widgets.Tooltip;
import me.shedaniel.rei.api.client.gui.widgets.TooltipContext;
import me.shedaniel.rei.api.common.entry.EntryStack;
import me.shedaniel.rei.impl.client.gui.widget.CachedEntryListRender;
import net.minecraft.class_1921;
import net.minecraft.class_332;
import net.minecraft.class_4588;
import net.minecraft.class_4597;
import org.jetbrains.annotations.Nullable;
import org.joml.Matrix4f;

public class CachingEntryRenderer implements BatchedEntryRenderer<Object, CachedEntryListRender.Sprite> {
    private final CachedEntryListRender.Sprite sprite;
    
    public CachingEntryRenderer(CachedEntryListRender.Sprite sprite) {
        this.sprite = sprite;
    }
    
    @Override
    public CachedEntryListRender.Sprite getExtraData(EntryStack<Object> entry) {
        return sprite;
    }
    
    @Override
    public int getBatchIdentifier(EntryStack<Object> entry, Rectangle bounds, CachedEntryListRender.Sprite extraData) {
        return 0;
    }
    
    @Override
    public void startBatch(EntryStack<Object> entry, CachedEntryListRender.Sprite extraData, class_332 graphics, float delta) {
    }
    
    @Override
    public void renderBase(EntryStack<Object> entry, CachedEntryListRender.Sprite extraData, class_332 graphics, class_4597.class_4598 immediate, Rectangle bounds, int mouseX, int mouseY, float delta) {
        class_4588 consumer = immediate.getBuffer(CachedEntryListRender.renderType.get());
        Matrix4f pose = graphics.method_51448().method_23760().method_23761();
        consumer.method_22918(pose, bounds.x, bounds.getMaxY(), 0).method_22913(extraData.u0, extraData.v1);
        consumer.method_22918(pose, bounds.getMaxX(), bounds.getMaxY(), 0).method_22913(extraData.u1, extraData.v1);
        consumer.method_22918(pose, bounds.getMaxX(), bounds.y, 0).method_22913(extraData.u1, extraData.v0);
        consumer.method_22918(pose, bounds.x, bounds.y, 0).method_22913(extraData.u0, extraData.v0);
    }
    
    @Override
    public void afterBase(EntryStack<Object> entry, CachedEntryListRender.Sprite extraData, class_332 graphics, float delta) {
    }
    
    @Override
    public void renderOverlay(EntryStack<Object> entry, CachedEntryListRender.Sprite extraData, class_332 graphics, class_4597.class_4598 immediate, Rectangle bounds, int mouseX, int mouseY, float delta) {
    }
    
    @Override
    public void endBatch(EntryStack<Object> entry, CachedEntryListRender.Sprite extraData, class_332 graphics, float delta) {
    }
    
    @Override
    public void render(EntryStack<Object> entry, class_332 graphics, Rectangle bounds, int mouseX, int mouseY, float delta) {
        graphics.method_25295(class_1921::method_62277, CachedEntryListRender.cachedTextureLocation, bounds.x, bounds.getMaxX(), bounds.y, bounds.getMaxY(), sprite.u0, sprite.u1, sprite.v0, sprite.v1, -1);
    }
    
    @Override
    @Nullable
    public Tooltip getTooltip(EntryStack<Object> entry, TooltipContext context) {
        return entry.getDefinition().getRenderer().getTooltip(entry.cast(), context);
    }
}

==> RoughlyEnoughItems-fabric-21.9.813-sources.jar: me/shedaniel/rei/impl/client/gui/widget/entrylist/CachingEntryRenderer.java <==
/*
 * This file is licensed under the MIT License, part of Roughly Enough Items.
 * Copyright (c) 2018, 2019, 2020, 2021, 2022, 2023 shedaniel
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */

package me.shedaniel.rei.impl.client.gui.widget.entrylist;

import me.shedaniel.math.Rectangle;
import me.shedaniel.rei.api.client.entry.renderer.EntryRenderer;
import me.shedaniel.rei.api.client.gui.widgets.Tooltip;
import me.shedaniel.rei.api.client.gui.widgets.TooltipContext;
import me.shedaniel.rei.api.common.entry.EntryStack;
import me.shedaniel.rei.impl.client.gui.widget.CachedEntryListRender;
import net.minecraft.class_10799;
import net.minecraft.class_332;
import org.jetbrains.annotations.Nullable;

public class CachingEntryRenderer implements EntryRenderer<Object> {
    private final CachedEntryListRender.Sprite sprite;
    
    public CachingEntryRenderer(CachedEntryListRender.Sprite sprite) {
        this.sprite = sprite;
    }
    
    @Override
    public void render(EntryStack<Object> entry, class_332 graphics, Rectangle bounds, int mouseX, int mouseY, float delta) {
        graphics.method_25295(class_10799.field_56883, CachedEntryListRender.cachedTextureLocation, bounds.x, bounds.getMaxX(), bounds.y, bounds.getMaxY(), sprite.u0, sprite.u1, sprite.v0, sprite.v1, -1);
    }
    
    @Override
    @Nullable
    public Tooltip getTooltip(EntryStack<Object> entry, TooltipContext context) {
        return entry.getDefinition().getRenderer().getTooltip(entry.cast(), context);
    }
}
